==> quickplot_0.1.0.orig.tar.gz: quickplot-0.1.0/initialize_Plot_struct.c <==
/***************************************************************
LanceMan's quickplot --- a fast interactive 2D plotter

Copyright (C) 1998  Lance Arsenault

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2
of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

***********************************************************************/
/* $Id: initialize_Plot_struct.c,v 1.1 1998/02/28 18:09:06 lance Exp $ */
#include "data.h"

void initialize_Plot_struct(Plot *plot) /* see data.h */
{
  plot->label_seperator =  DEFAULT_LABEL_SEPERATOR;
  plot->labels = NULL;
  plot->flag = 0;
  plot->dim = 0;
  plot->infiles = NULL;
  plot->skip_lines = 0;
  plot->num_points = NULL;
  plot->max = NULL;
  plot->min = NULL;
  plot->data = NULL;
  plot->num_plots = 0;
  plot->label = NULL;
  plot->plot_opt = NULL;
  plot->point_color = NULL;
  plot->line_color = NULL;
  plot->list = NULL;
  plot->shift = NULL;
  plot->scale = NULL;
  plot->start = NULL;
  plot->end = NULL;
  plot->zoom_count = 0;
  plot->num_zoom = 0;
  plot->z_shift = NULL;
  plot->z_scale = NULL;
}

==> quickplot_0.4.4.orig.tar.gz: quickplot-0.4.4/initialize_Plot_struct.c <==
/***************************************************************
LanceMan's quickplot --- a fast interactive 2D plotter

Copyright (C) 1998, 1999  Lance Arsenault

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2
of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Or look at http://www.gnu.org/copyleft/gpl.html .

**********************************************************************/
/* $Id: initialize_Plot_struct.c,v 1.1 1998/02/28 18:09:06 lance Exp $ */
#include "data.h"

void initialize_Plot_struct(Plot *plot) /* see data.h */
{
  plot->label_seperator =  DEFAULT_LABEL_SEPERATOR;
  plot->labels = NULL;
  plot->flag = 0;
  plot->dim = 0;
  plot->infiles = NULL;
  plot->skip_lines = 0;
  plot->num_points = NULL;
  plot->max = NULL;
  plot->min = NULL;
  plot->data = NULL;
  plot->num_plots = 0;
  plot->label = NULL;
  plot->plot_opt = NULL;
  plot->point_color = NULL;
  plot->line_color = NULL;
  plot->list = NULL;
  plot->shift = NULL;
  plot->scale = NULL;
  plot->start = NULL;
  plot->end = NULL;
  plot->zoom_count = 0;
  plot->num_zoom = 0;
  plot->z_shift = NULL;
  plot->z_scale = NULL;
}
